@@ -150,3 +150,11 @@ def plone_mockup_pattern():
     reg.plonecli_alias = "mockup_pattern"
     reg.depend_on = "plone_addon"
     return reg
+
+
+def plone_form():
+    reg = RegEntry()
+    reg.template = "bobtemplates.plone:form"
+    reg.plonecli_alias = "form"
+    reg.depend_on = "plone_addon"
+    return reg
