@@ -2,10 +2,12 @@
 """Generate view."""
 
 from bobtemplates.plone.base import base_prepare_renderer
+from bobtemplates.plone.base import CONTENT_TYPE_INTERFACES
 from bobtemplates.plone.base import echo
 from bobtemplates.plone.base import git_commit
 from bobtemplates.plone.base import update_file
 from bobtemplates.plone.base import ZCML_NAMESPACES
+from bobtemplates.plone.utils import run_black
 from bobtemplates.plone.utils import run_isort
 from lxml import etree
 from mrbob.bobexceptions import SkipQuestion
@@ -40,7 +42,7 @@ def get_view_template_name_from_python_class(configurator, question):
 def check_python_class_answer(configurator, question):
     if not configurator.variables["view_python_class"]:
         raise SkipQuestion(
-            u"No python class, so we skip python class name question."
+            "No python class, so we skip python class name question."
         )  # NOQA: E501
 
 
@@ -50,78 +52,73 @@ def check_view_template_answer(configurator, question):
         and not configurator.variables["view_python_class"]
     ):  # NOQA: E501
         raise ValidationError(
-            u"View must at least have a template or a python class"
+            "View must at least have a template or a python class"
         )  # NOQA: E501
     elif not configurator.variables["view_template"]:
         raise SkipQuestion(
-            u"No view template, so we skip view template name question."
+            "No view template, so we skip view template name question."
         )  # NOQA: E501
 
 
+def get_view_configuration(configurator):
+    """return a dict with view configuration used for registration in zcml"""
+    config = dict()
+    config["name"] = configurator.variables["view_name"]
+    # get Interface by content type or use the string it self as interface
+    config["for"] = "{0}".format(
+        CONTENT_TYPE_INTERFACES.get(
+            configurator.variables["view_register_for"],
+            configurator.variables["view_register_for"],
+        )
+    )
+    if configurator.variables["view_template"]:
+        config["template"] = "{0}.pt".format(
+            configurator.variables["view_template_name"]
+        )
+    if configurator.variables["view_python_class"]:
+        config["class"] = ".{0}.{1}".format(
+            configurator.variables["view_python_file_name"],
+            configurator.variables["view_python_class_name"],
+        )
+    # if configurator.variables["view_permission"]:
+    config["permission"] = "zope2.View"
+    return config
+
+
 def _update_views_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     directory_path = configurator.variables["package_folder"] + "/views/"
     file_path = directory_path + file_name
     configure_example_file_path = (
         configurator.variables["package_folder"] + "/views/configure.zcml.example"
-    )  # NOQA: E501
+    )
     file_list = os.listdir(os.path.dirname(directory_path))
     if file_name not in file_list:
         os.rename(configure_example_file_path, file_path)
 
     match_str = "-*- extra stuff goes here -*-"
 
-    if (
-        configurator.variables["view_template"]
-        and configurator.variables["view_python_class"]
-    ):  # NOQA: E501
-        insert_str = """
+    view_config = get_view_configuration(configurator)
+    insert_str = """
   <browser:page
     name="{0}"
-    for="Products.CMFCore.interfaces.IFolderish"
-    class=".{1}.{2}"
-    template="{3}.pt"
-    permission="zope2.View"
-    />
+    for="{1}"
 """.format(
-            configurator.variables["view_name"],
-            configurator.variables["view_python_file_name"],
-            configurator.variables["view_python_class_name"],
-            configurator.variables["view_template_name"],
-        )
+        view_config["name"],
+        view_config["for"],
+    )
+    if "class" in view_config:
+        insert_str += '    class="{0}"\n'.format(view_config["class"])
+    if "template" in view_config:
+        insert_str += '    template="{0}"\n'.format(view_config["template"])
+    if "permission" in view_config:
+        insert_str += '    permission="{0}"\n'.format(view_config["permission"])
+    insert_str += '    layer="{0}.interfaces.I{1}"\n'.format(
+        configurator.variables["package.dottedname"],
+        configurator.variables["package.browserlayer"],
+    )
+    insert_str += "    />\n"
 
-    if (
-        configurator.variables["view_template"]
-        and not configurator.variables["view_python_class"]
-    ):  # NOQA: E501
-        insert_str = """
-  <browser:page
-    name="{0}"
-    for="Products.CMFCore.interfaces.IFolderish"
-    template="{1}.pt"
-    permission="zope2.View"
-    />
-""".format(
-            configurator.variables["view_name"],
-            configurator.variables["view_template_name"],
-        )
-
-    if (
-        not configurator.variables["view_template"]
-        and configurator.variables["view_python_class"]
-    ):  # NOQA: E501
-        insert_str = """
-  <browser:page
-    name="{0}"
-    for="Products.CMFCore.interfaces.IFolderish"
-    class=".{1}.{2}"
-    permission="zope2.View"
-    />
-""".format(
-            configurator.variables["view_name"],
-            configurator.variables["view_python_file_name"],
-            configurator.variables["view_python_class_name"],
-        )
     with open(file_path, "r") as xml_file:
         parser = etree.XMLParser(remove_blank_text=True)
         tree = etree.parse(xml_file, parser)
@@ -131,8 +128,8 @@ def _update_views_configure_zcml(configurator):
         )
         if len(tree_root.xpath(view_xpath, namespaces=ZCML_NAMESPACES)):
             echo(
-                u"{0} already in configure.zcml, do you really want to add this config?"
-                u"\n\n{1}\n [y/N]: ".format(
+                "{0} already in configure.zcml, do you really want to add this config?"
+                "\n\n{1}\n [y/N]: ".format(
                     configurator.variables["view_name"],
                     insert_str,
                 ),
@@ -148,7 +145,7 @@ def _update_views_configure_zcml(configurator):
 
 
 def _update_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/" + file_name
     namespaces = "{http://namespaces.zope.org/zope}"
 
@@ -173,20 +170,20 @@ def _update_configure_zcml(configurator):
 def _delete_unwanted_files(configurator):
     directory_path = configurator.variables["package_folder"] + "/views/"
     if not configurator.variables["view_template"]:
-        file_name = u"{0}.pt".format(
+        file_name = "{0}.pt".format(
             configurator.variables["view_template_name"],
         )
         file_path = directory_path + file_name
         os.remove(file_path)
 
     elif not configurator.variables["view_python_class"]:
-        file_name = u"{0}.py".format(
+        file_name = "{0}.py".format(
             configurator.variables["view_python_file_name"],
         )
         file_path = directory_path + file_name
         os.remove(file_path)
 
-    file_name = u"configure.zcml.example"
+    file_name = "configure.zcml.example"
     file_list = os.listdir(os.path.dirname(directory_path))
     if file_name in file_list:
         file_path = directory_path + file_name
@@ -231,6 +228,7 @@ def post_renderer(configurator):
     _update_views_configure_zcml(configurator)
     _delete_unwanted_files(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add view: {0}".format(
