@@ -11,7 +11,7 @@ import os
 def test_pre_renderer(tmpdir):
     package_root = tmpdir.strpath + "/collective.todo"
     package_path = init_package_base_structure(package_root)
-    target_path = os.path.join(package_path, 'profiles/default')
+    target_path = os.path.join(package_path, "profiles/default")
 
     template = """<?xml version='1.0' encoding='UTF-8'?>
 <metadata>
@@ -21,15 +21,15 @@ def test_pre_renderer(tmpdir):
   </dependencies>
 </metadata>
 """
-    with open(os.path.join(target_path, 'metadata.xml'), 'w') as f:
+    with open(os.path.join(target_path, "metadata.xml"), "w") as f:
         f.write(template)
     configurator = Configurator(
-        template='bobtemplates.plone:upgrade_step',
+        template="bobtemplates.plone:upgrade_step",
         target_directory=package_path,
         variables={
-            'package_folder': package_path,
-            'upgrade_step_title': 'Add cool index and reindex it',
-            'upgrade_step_description': 'We add an index and reindex it with existing content.',
+            "package_folder": package_path,
+            "upgrade_step_title": "Add cool index and reindex it",
+            "upgrade_step_description": "We add an index and reindex it with existing content.",
         },
     )
     assert configurator
@@ -40,9 +40,9 @@ def test_pre_renderer(tmpdir):
 
 
 def test_post_renderer(tmpdir):
-    target_path = tmpdir.strpath + '/collective.todo'
-    package_path = target_path + '/src/collective/todo'
-    profiles_path = package_path + '/profiles/default'
+    target_path = tmpdir.strpath + "/collective.todo"
+    package_path = target_path + "/src/collective/todo"
+    profiles_path = package_path + "/profiles/default"
     os.makedirs(target_path)
     os.makedirs(package_path)
     os.makedirs(profiles_path)
@@ -55,21 +55,21 @@ def test_post_renderer(tmpdir):
   </dependencies>
 </metadata>
 """
-    with open(os.path.join(profiles_path + '/metadata.xml'), 'w') as f:
+    with open(os.path.join(profiles_path + "/metadata.xml"), "w") as f:
         f.write(template)
 
     template = """
 [main]
 version=5.1
 """
-    with open(os.path.join(target_path + '/bobtemplate.cfg'), 'w') as f:
+    with open(os.path.join(target_path + "/bobtemplate.cfg"), "w") as f:
         f.write(template)
 
     template = """
     dummy
     '-*- Extra requirements: -*-'
 """
-    with open(os.path.join(target_path + '/setup.py'), 'w') as f:
+    with open(os.path.join(target_path + "/setup.py"), "w") as f:
         f.write(template)
 
     template = """
@@ -83,18 +83,18 @@ version=5.1
 
     </configure>
 """
-    with open(os.path.join(package_path + '/configure.zcml'), 'w') as f:
+    with open(os.path.join(package_path + "/configure.zcml"), "w") as f:
         f.write(template)
     configurator = Configurator(
-        template='bobtemplates.plone:upgrade_step',
+        template="bobtemplates.plone:upgrade_step",
         target_directory=package_path,
         bobconfig={
-            'non_interactive': True,
+            "non_interactive": True,
         },
         variables={
-            'plone.version': '5.1',
-            'upgrade_step_title': 'Add cool index and reindex it',
-            'upgrade_step_description': 'We add an index and reindex it with existing content.',
+            "plone.version": "5.1",
+            "upgrade_step_title": "Add cool index and reindex it",
+            "upgrade_step_description": "We add an index and reindex it with existing content.",
         },
     )
 
@@ -107,7 +107,7 @@ version=5.1
 def test_read_source_version(tmpdir):
     package_root = tmpdir.strpath + "/collective.todo"
     package_path = init_package_base_structure(package_root)
-    target_path = os.path.join(package_path, 'profiles/default')
+    target_path = os.path.join(package_path, "profiles/default")
 
     template = """<?xml version='1.0' encoding='UTF-8'?>
 <metadata>
@@ -117,19 +117,19 @@ def test_read_source_version(tmpdir):
   </dependencies>
 </metadata>
 """
-    with open(os.path.join(target_path, 'metadata.xml'), 'w') as f:
+    with open(os.path.join(target_path, "metadata.xml"), "w") as f:
         f.write(template)
     configurator = Configurator(
-        template='bobtemplates.plone:upgrade_step',
+        template="bobtemplates.plone:upgrade_step",
         target_directory=package_path,
         bobconfig={
-            'non_interactive': True,
+            "non_interactive": True,
         },
         variables={
-            'plone.version': '5.1',
-            'package_folder': package_path,
-            'upgrade_step_title': 'Add cool index and reindex it',
-            'upgrade_step_description': 'We add an index and reindex it with existing content.',
+            "plone.version": "5.1",
+            "package_folder": package_path,
+            "upgrade_step_title": "Add cool index and reindex it",
+            "upgrade_step_description": "We add an index and reindex it with existing content.",
         },
     )
     assert configurator
@@ -139,7 +139,7 @@ def test_read_source_version(tmpdir):
 def test_write_dest_version(tmpdir):
     package_root = tmpdir.strpath + "/collective.todo"
     package_path = init_package_base_structure(package_root)
-    target_path = os.path.join(package_path, 'profiles/default')
+    target_path = os.path.join(package_path, "profiles/default")
 
     template = """<?xml version='1.0' encoding='UTF-8'?>
 <metadata>
@@ -149,20 +149,20 @@ def test_write_dest_version(tmpdir):
   </dependencies>
 </metadata>
 """
-    with open(os.path.join(target_path, 'metadata.xml'), 'w') as f:
+    with open(os.path.join(target_path, "metadata.xml"), "w") as f:
         f.write(template)
     configurator = Configurator(
-        template='bobtemplates.plone:upgrade_step',
+        template="bobtemplates.plone:upgrade_step",
         target_directory=package_path,
         bobconfig={
-            'non_interactive': True,
+            "non_interactive": True,
         },
         variables={
-            'plone.version': '5.1',
-            'package_folder': package_path,
-            'upgrade_step_title': 'Add cool index and reindex it',
-            'upgrade_step_dest_version': 1005,
-            'upgrade_step_description': 'We add an index and reindex it with existing content.',
+            "plone.version": "5.1",
+            "package_folder": package_path,
+            "upgrade_step_title": "Add cool index and reindex it",
+            "upgrade_step_dest_version": 1005,
+            "upgrade_step_description": "We add an index and reindex it with existing content.",
         },
     )
     assert configurator
