@@ -23,7 +23,7 @@ def test_get_view_name():
         variables={"view_python_class": True, "view_python_class_name": "DemoView"},
     )
     view.get_view_name_from_python_class(configurator, question)
-    assert question.default == 'demo-view'
+    assert question.default == "demo-view"
 
 
 def test_get_view_template_name():
@@ -35,7 +35,7 @@ def test_get_view_template_name():
         variables={"view_python_class": True, "view_python_class_name": "DemoView"},
     )
     view.get_view_template_name_from_python_class(configurator, question)
-    assert question.default == 'demo_view'
+    assert question.default == "demo_view"
 
 
 def test_python_class_true():
@@ -119,10 +119,13 @@ def test_update_views_configure_zcml(tmpdir):
             "view_python_class": True,
             "view_python_class_name": "MyView",
             "view_python_file_name": "py_view",
+            "view_register_for": "Folder",
             "view_name": "py-view",
             "view_template": True,
             "view_template_name": "pt_view",
             "package_folder": package_path,
+            "package.dottedname": "collective.sample",
+            "package.browserlayer": "CollectiveSampleLayer",
         },
     )
     view._update_views_configure_zcml(configurator)
@@ -137,10 +140,11 @@ def test_update_views_configure_zcml(tmpdir):
 
   <browser:page
     name="py-view"
-    for="Products.CMFCore.interfaces.IFolderish"
+    for="plone.app.contenttypes.interfaces.IFolder"
     class=".py_view.MyView"
     template="pt_view.pt"
     permission="zope2.View"
+    layer="collective.sample.interfaces.ICollectiveSampleLayer"
     />
 
 </configure>
@@ -178,9 +182,12 @@ def test_update_views_configure_zcml_without_template(tmpdir):
             "view_python_class": True,
             "view_python_class_name": "MyView",
             "view_python_file_name": "py_view",
+            "view_register_for": "plone.app.contenttypes.interfaces.IFolder",
             "view_name": "py-view",
             "view_template": False,
             "package_folder": package_path,
+            "package.dottedname": "collective.sample",
+            "package.browserlayer": "CollectiveSampleLayer",
         },
     )
     view._update_views_configure_zcml(configurator)
@@ -195,9 +202,10 @@ def test_update_views_configure_zcml_without_template(tmpdir):
 
   <browser:page
     name="py-view"
-    for="Products.CMFCore.interfaces.IFolderish"
+    for="plone.app.contenttypes.interfaces.IFolder"
     class=".py_view.MyView"
     permission="zope2.View"
+    layer="collective.sample.interfaces.ICollectiveSampleLayer"
     />
 
 </configure>
@@ -236,7 +244,10 @@ def test_update_views_configure_zcml_without_python_class(tmpdir):
             "view_name": "py-view",
             "view_template": True,
             "view_template_name": "pt_view",
+            "view_register_for": "*",
             "package_folder": package_path,
+            "package.dottedname": "collective.sample",
+            "package.browserlayer": "CollectiveSampleLayer",
         },
     )
     view._update_views_configure_zcml(configurator)
@@ -251,9 +262,10 @@ def test_update_views_configure_zcml_without_python_class(tmpdir):
 
   <browser:page
     name="py-view"
-    for="Products.CMFCore.interfaces.IFolderish"
+    for="*"
     template="pt_view.pt"
     permission="zope2.View"
+    layer="collective.sample.interfaces.ICollectiveSampleLayer"
     />
 
 </configure>
@@ -277,6 +289,7 @@ def test_delete_unwanted_files_template(tmpdir):
             "view_name": "my-new-view",
             "view_python_class": False,
             "view_python_class_name": "NewView",
+            "view_register_for": "*",
             "view_template": True,
             "view_template_name": "new_view",
             "plone.version": "5.1",
@@ -287,8 +300,8 @@ def test_delete_unwanted_files_template(tmpdir):
     base.set_global_vars(configurator)
     configurator.render()  # pre/render/post
     # as the post_rederer also calls delete_unwanted_files. we don't need to call here
-    python_file_name = configurator.variables.get('view_python_file_name') + '.py'
-    template_file_name = configurator.variables.get('view_template_name') + '.pt'
+    python_file_name = configurator.variables.get("view_python_file_name") + ".py"
+    template_file_name = configurator.variables.get("view_template_name") + ".pt"
     python_file_path = os.path.join(views_path + python_file_name)
     template_file_path = os.path.join(views_path + template_file_name)
     assert os.path.isfile(template_file_path)
@@ -308,6 +321,7 @@ def test_delete_unwanted_files_python(tmpdir):
             "view_name": "my-new-view",
             "view_python_class": True,
             "view_python_class_name": "NewView",
+            "view_register_for": "*",
             "view_template": False,
             "view_template_name": "new_view",
             "plone.version": "5.1",
@@ -318,8 +332,8 @@ def test_delete_unwanted_files_python(tmpdir):
     base.set_global_vars(configurator)
     configurator.render()  # pre/render/post
     # as the post_rederer also calls delete_unwanted_files. we don't need to call here
-    python_file_name = configurator.variables.get('view_python_file_name') + '.py'
-    template_file_name = configurator.variables.get('view_template_name') + '.pt'
+    python_file_name = configurator.variables.get("view_python_file_name") + ".py"
+    template_file_name = configurator.variables.get("view_template_name") + ".pt"
     python_file_path = os.path.join(views_path + python_file_name)
     template_file_path = os.path.join(views_path + template_file_name)
     assert not os.path.isfile(template_file_path)
@@ -372,6 +386,7 @@ def test_pre_renderer(tmpdir):
             "view_base_class": "BrowserView",
             "view_template": True,
             "view_template_name": "new_view",
+            "view_register_for": "plone.app.contenttypes.interfaces.IFolder",
             "plone.version": "5.1",
         },
     )
@@ -389,6 +404,7 @@ def test_pre_renderer(tmpdir):
         variables={
             "view_name": "my-new-view",
             "view_python_class": False,
+            "view_register_for": "*",
             "view_template": False,
             "plone.version": "5.1",
         },
@@ -421,6 +437,7 @@ def test_post_renderer(tmpdir):
             "view_python_class": True,
             "view_python_class_name": "NewView",
             "view_base_class": "BrowserView",
+            "view_register_for": "*",
             "view_template": True,
             "view_template_name": "new_view",
             "plone.version": "5.1",
